aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/config/operation.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/config/operation.cxx')
-rw-r--r--libbuild2/config/operation.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/libbuild2/config/operation.cxx b/libbuild2/config/operation.cxx
index 3758c87..2138986 100644
--- a/libbuild2/config/operation.cxx
+++ b/libbuild2/config/operation.cxx
@@ -306,7 +306,7 @@ namespace build2
// inherited. We might also not have any value at all (see
// unconfigured()).
//
- if (!l.defined () || (l->null && sv.flags & omit_null))
+ if (!l.defined () || (l->null && sv.flags & save_null_omitted))
continue;
// Handle inherited from outer scope values.
@@ -449,11 +449,11 @@ namespace build2
first = false;
}
// Handle the save_commented flag.
//
if ((org.first.defined () && org.first->extra) && // Default value.
org.first == ovr.first && // Not overriden.
- (sv.flags & save_commented) == save_commented)
+ (sv.flags & save_default_commented) != 0)
{
os << '#' << n << " =" << endl;
continue;
@@ -449,11 +449,11 @@ namespace build2
first = false;
}
- // Handle the save_commented flag.
+ // Handle the save_default_commented flag.
//
if ((org.first.defined () && org.first->extra) && // Default value.